from .templateconfig import ProjectType

TEMPLATE_MAP = {
   ProjectType.ANDROID: "android-kavia",
   ProjectType.ANGULAR: "angular-kavia",
   ProjectType.ASTRO: "astro-kavia",
   ProjectType.DJANGO: "django-kavia",
   ProjectType.DOTNET: "dotnet-kavia",
   ProjectType.EXPRESS: "express-kavia",
   ProjectType.FASTAPI: "fastapi-kavia",
   ProjectType.FLASK: "flask-kavia",
   ProjectType.SPRINGBOOT: "springboot-kavia",
   ProjectType.FLUTTER: "flutter-kavia",
   ProjectType.KOTLIN: "kotlin-kavia",
   ProjectType.LIGHTNINGJS: "lightningjs-kavia",
   ProjectType.NATIVESCRIPT: "nativescript-kavia",
   ProjectType.NEXTJS: "nextjs-kavia",
   ProjectType.SOLANANEXTJS: "solananextjs-kavia",
   ProjectType.NUXT: "nuxt-kavia",
   ProjectType.QWIK: "qwik-kavia",
   ProjectType.REACT : "react-kavia",
   ProjectType.REACT_NATIVE : "reactnative-kavia",
   ProjectType.REMIX : "remix-kavia",
   ProjectType.REMOTION: "remotion-kavia",
   ProjectType.SLIDEV: "slidev-kavia",
   ProjectType.SVELTE : "svelte-kavia",
   ProjectType.TYPESCRIPT: "typescript-kavia",
   ProjectType.VITE: "vite-kavia",
   ProjectType.VUE: "vue-kavia",
   ProjectType.POSTGRESQL: "postgresql-kavia",
   ProjectType.MONGODB: "mongodb-kavia",
   ProjectType.MYSQL: "mysql-kavia",
   ProjectType.SQLITE: "sqlite-kavia",
   ProjectType.NATIVE: "native",
}
